@@ -10,10 +10,16 @@ from tako.types.common.exceptions import (
 )
 from tako.types.knowledge_search.types import (
     KnowledgeSearchOutputs,
+    KnowledgeSearchRequestOutputSettings,
     KnowledgeSearchResults,
     KnowledgeSearchSourceIndex,
 )
-from tako.types.visualize.types import TakoDataFormatDataset, VisualizeRequest
+from tako.types.visualize.types import (
+    TakoDataFormatDataset,
+    UserRequestedVizComponentType,
+    VisualizeRequest,
+    VisualizeSupportedModels,
+)
 
 TAKO_API_KEY = os.getenv("TAKO_API_KEY", None)
 TAKO_SERVER_URL = os.getenv("TAKO_SERVER_URL", "https://trytako.com/")
@@ -38,6 +44,8 @@ class TakoClient:
         source_indexes: Optional[List[KnowledgeSearchSourceIndex]] = [
             KnowledgeSearchSourceIndex.TAKO,
         ],
+        output_settings: Optional[KnowledgeSearchRequestOutputSettings] = None,
+        country_code: Optional[str] = "US",
     ) -> KnowledgeSearchResults:
         """
         Search for knowledge cards based on a text query.
@@ -60,6 +68,10 @@ class TakoClient:
         }
         if source_indexes:
             payload["source_indexes"] = source_indexes
+        if output_settings:
+            payload["output_settings"] = output_settings.model_dump()
+        if country_code:
+            payload["country_code"] = country_code
 
         response = requests.post(url, json=payload, headers={"X-API-Key": self.api_key})
         try:
@@ -98,6 +110,9 @@ class TakoClient:
         tako_formatted_dataset: Optional[TakoDataFormatDataset] = None,
         file_id: Optional[str] = None,
         query: Optional[str] = None,
+        model: Optional[VisualizeSupportedModels] = None,
+        output_settings: Optional[KnowledgeSearchRequestOutputSettings] = None,
+        viz_component_type: Optional[UserRequestedVizComponentType] = None,
     ) -> KnowledgeSearchResults:
         url = f"{self.server_url}/api/{self.api_version}/beta/visualize"
         if tako_formatted_dataset is None and file_id is None:
@@ -112,18 +127,28 @@ class TakoClient:
             tako_formatted_dataset=tako_formatted_dataset,
             file_id=file_id,
             query=query,
+            model=model,
+            output_settings=output_settings,
+            viz_component_type=viz_component_type,
         )
         payload = visualize_request.model_dump()
         response = requests.post(url, json=payload, headers={"X-API-Key": self.api_key})
         raise_exception_from_response(response)
         return KnowledgeSearchResults.model_validate(response.json())
 
-    def _get_presigned_url(self, file_name: str) -> dict:
+    def _get_presigned_url(
+        self, file_name: str, file_context: Optional[str] = None, source: Optional[str] = None
+    ) -> dict:
         url = f"{self.server_url}/api/{self.api_version}/beta/file_upload_url"
+        params = {"file_name": file_name}
+        if file_context:
+            params["file_context"] = file_context
+        if source:
+            params["source"] = source
         response = requests.get(
-            url, 
-            params={"file_name": file_name}, 
-            headers={"X-API-Key": self.api_key, "Accept": "application/json"}
+            url,
+            params=params,
+            headers={"X-API-Key": self.api_key, "Accept": "application/json"},
         )
         raise_exception_from_response(response)
         return response.json()
@@ -134,47 +159,47 @@ class TakoClient:
             # Prepare form data with all required fields
             files = {"file": (os.path.basename(file_path), f)}
             data = upload_info["fields"]
-            
+
             # POST to the presigned URL
             response = requests.post(upload_info["url"], files=files, data=data)
             response.raise_for_status()  # Raises exception for HTTP errors
 
-    def beta_upload_file(self, file_path: str) -> str:
+    def beta_upload_file(
+        self, file_path: str, file_context: Optional[str] = None, source: Optional[str] = None
+    ) -> str:
         """Upload a file and return the file ID.
-        
+
         Args:
             file_path: Path to the file to upload.
-            
+
         Returns:
             The file ID.
-            
+
         """
         file_name = os.path.basename(file_path)
-        
+
         # Step 1: Get presigned URL and upload fields
-        upload_info = self._get_presigned_url(file_name)
-        
+        upload_info = self._get_presigned_url(
+            file_name=file_name, file_context=file_context, source=source
+        )
+
         # Step 2: Upload the file using the presigned URL
         self._upload_file(file_path, upload_info)
-        
+
         # Return the file ID
         return upload_info["file_id"]
-    
-    def beta_file_connector(
-        self, 
-        file_url: str, 
-        file_id: Optional[str] = None
-    ) -> dict:
+
+    def beta_file_connector(self, file_url: str, file_id: Optional[str] = None) -> dict:
         """
         Connect to a hosted file via URL.
-        
+
         Args:
             file_url: URL of the file to connect to.
             file_id: ID of the file to connect to. If not provided, a new file ID will be generated.
-            
+
         Returns:
             Dictionary containing 'message' and 'id' fields.
-            
+
         Raises:
             APIException: If the API returns an error.
         """
@@ -184,7 +209,7 @@ class TakoClient:
         }
         if file_id is not None:
             payload["file_id"] = file_id
-            
+
         response = requests.post(url, json=payload, headers={"X-API-Key": self.api_key})
         raise_exception_from_response(response)
         return response.json()
@@ -271,6 +296,7 @@ class AsyncTakoClient:
         tako_formatted_dataset: Optional[TakoDataFormatDataset] = None,
         file_id: Optional[str] = None,
         query: Optional[str] = None,
+        model: Optional[VisualizeSupportedModels] = None,
         timeout_seconds: Optional[float] = None,
     ) -> KnowledgeSearchResults:
         url = f"{self.server_url}/api/{self.api_version}/beta/visualize"
@@ -286,6 +312,7 @@ class AsyncTakoClient:
             tako_formatted_dataset=tako_formatted_dataset,
             file_id=file_id,
             query=query,
+            model=model,
         )
         payload = visualize_request.model_dump()
         async with httpx.AsyncClient(
@@ -296,30 +323,43 @@ class AsyncTakoClient:
             )
             raise_exception_from_response(response)
             return KnowledgeSearchResults.model_validate(response.json())
-        
-    async def _get_presigned_url(self, file_name: str, timeout_seconds: Optional[float] = None) -> dict:
+
+    async def _get_presigned_url(
+        self,
+        file_name: str,
+        timeout_seconds: Optional[float] = None,
+        file_context: Optional[str] = None,
+        source: Optional[str] = None,
+    ) -> dict:
         """Async get presigned URL for file upload."""
         url = f"{self.server_url}/api/{self.api_version}/beta/file_upload_url"
+        params = {"file_name": file_name}
+        if file_context:
+            params["file_context"] = file_context
+        if source:
+            params["source"] = source
         async with httpx.AsyncClient(
             timeout=timeout_seconds or self.default_timeout_seconds
         ) as client:
             response = await client.get(
-                url, 
-                params={"file_name": file_name}, 
-                headers={"X-API-Key": self.api_key, "Accept": "application/json"}
+                url,
+                params=params,
+                headers={"X-API-Key": self.api_key, "Accept": "application/json"},
             )
             raise_exception_from_response(response)
             return response.json()
 
-    async def _upload_file(self, file_path: str, upload_info: dict, timeout_seconds: Optional[float] = None) -> None:
+    async def _upload_file(
+        self, file_path: str, upload_info: dict, timeout_seconds: Optional[float] = None
+    ) -> None:
         """Async upload file using presigned URL and fields."""
         # Run file reading in a thread pool executor
         file_content = await asyncio.to_thread(lambda: open(file_path, "rb").read())
-        
+
         # Prepare form data with all required fields
         files = {"file": (os.path.basename(file_path), file_content)}
         data = upload_info["fields"]
-        
+
         # POST to the presigned URL
         async with httpx.AsyncClient(
             timeout=timeout_seconds or self.default_timeout_seconds
@@ -327,36 +367,48 @@ class AsyncTakoClient:
             response = await client.post(upload_info["url"], files=files, data=data)
             response.raise_for_status()  # Raises exception for HTTP errors
 
-    async def beta_upload_file(self, file_path: str, timeout_seconds: Optional[float] = None) -> str:
+    async def beta_upload_file(
+        self,
+        file_path: str,
+        timeout_seconds: Optional[float] = None,
+        file_context: Optional[str] = None,
+        source: Optional[str] = None,
+    ) -> str:
         """Async upload a file and return the file ID."""
         file_name = os.path.basename(file_path)
-        
+
         # Step 1: Get presigned URL and upload fields
-        upload_info = await self._get_presigned_url(file_name, timeout_seconds)
-        
+        upload_info = await self._get_presigned_url(
+            file_name=file_name,
+            timeout_seconds=timeout_seconds,
+            file_context=file_context,
+            source=source,
+        )
+
         # Step 2: Upload the file using the presigned URL
         await self._upload_file(file_path, upload_info, timeout_seconds)
-        
+
         # Return the file ID
         return upload_info["file_id"]
 
     async def beta_file_connector(
-        self, 
-        file_url: str, 
+        self,
+        file_url: str,
         file_id: Optional[str] = None,
-        timeout_seconds: Optional[float] = None
+        timeout_seconds: Optional[float] = None,
+        source: Optional[str] = None,
     ) -> dict:
         """
         Async connect your file to Tako for visualization and analysis.
-        
+
         Args:
             file_url: URL of the file to connect to.
             file_id: ID of the file to connect to. If not provided, a new file ID will be generated.
             timeout_seconds: Timeout for the request.
-            
+
         Returns:
             Dictionary containing 'message' and 'id' fields.
-            
+
         Raises:
             APIException: If the API returns an error.
         """
@@ -366,7 +418,8 @@ class AsyncTakoClient:
         }
         if file_id is not None:
             payload["file_id"] = file_id
-            
+        if source:
+            payload["source"] = source
         async with httpx.AsyncClient(
             timeout=timeout_seconds or self.default_timeout_seconds
         ) as client:
@@ -375,4 +428,3 @@ class AsyncTakoClient:
             )
             raise_exception_from_response(response)
             return response.json()
-
