@@ -1,8 +1,8 @@
 from enum import Enum
-from typing import Union
 
 from pydantic import BaseModel
 
+
 class APIErrorType(str, Enum):
     BAD_REQUEST = "BAD_REQUEST"
     AUTHENTICATION_ERROR = "AUTHENTICATION_ERROR"
@@ -39,8 +39,3 @@ class RateLimitExceededError(BaseAPIError):
 
 class PaymentRequiredError(BaseAPIError):
     error_type: APIErrorType = APIErrorType.PAYMENT_REQUIRED
-
-
-APIError = Union[PaymentRequiredError, RateLimitExceededError, RelevantResultsNotFoundError, InternalServerError, AuthenticationError, BadRequestError]
-
-
