@@ -3,6 +3,17 @@ from typing import Optional, Union
 
 from pydantic import BaseModel, Field
 
+from tako.types.knowledge_search.types import KnowledgeSearchRequestOutputSettings
+
+class VisualizeSupportedModels(str, Enum):
+    O3 = "o3"
+    O4_MINI = "o4-mini"
+    QWEN_3_32B = "qwen-3-32b"
+    LLAMA_3_3_70B = "llama-3.3-70b"
+    QWEN_3_CODER_480B = "qwen-3-coder-480b"
+    QWEN_3_235B_INSTRUCT = "qwen-3-235b-a22b-instruct-2507"
+    QWEN_3_235B_THINKING = "qwen-3-235b-a22b-thinking-2507"
+    GPT_OSS_120B = "gpt-oss-120b"
 
 class TakoDataFormatValueType(str, Enum):
     STRING = "string"
@@ -253,6 +264,15 @@ There are two common problems you find in data that are ingested that make them
    "unstack" or "pivot" the multiple rows into columns (ie go from long to wide.)
 """
 
+class UserRequestedVizComponentType(str, Enum):
+    BAR = "bar"
+    TIMESERIES = "timeseries"
+    PIE = "pie"
+    SCATTER = "scatter"
+    BOXPLOT = "boxplot"
+    HEATMAP = "heatmap"
+    TIMELINE = "timeline"
+    WATERFALL = "waterfall"
 
 class VisualizeRequest(BaseModel):
     tako_formatted_dataset: Optional[TakoDataFormatDataset] = Field(
@@ -264,3 +284,20 @@ class VisualizeRequest(BaseModel):
     query: Optional[str] = Field(
         description="Query with instructions to visualize the dataset", default=None
     )
+
+    output_settings: Optional[KnowledgeSearchRequestOutputSettings] = Field(
+        description="Settings for controlling outputs of the visualize request",
+        default=None,
+    )
+
+    viz_component_type: Optional[UserRequestedVizComponentType] = Field(
+        description="The type of visualization component to use",
+        default=None,
+    )
+    model: Optional[VisualizeSupportedModels] = Field(
+        description="The model to use for the visualization",
+        default=None,
+    )
+
+
+
